<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en_GB">
<context>
    <name>AboutDialog</name>
    <message>
        <source>cuteTube-QML - 0.3.9</source>
        <translation type="obsolete">cuteTube-QML - 0.3.9 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.3.10</source>
        <translation type="obsolete">cuteTube-QML - 0.3.10 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.4.1</source>
        <translation type="obsolete">cuteTube-QML - 0.4.1</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.4.2</source>
        <translation type="obsolete">cuteTube-QML - 0.4.2</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.4.4</source>
        <translation type="obsolete">cuteTube-QML - 0.4.4 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.5.1</source>
        <translation type="obsolete">cuteTube-QML - 0.5.1 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.1</source>
        <translation type="obsolete">cuteTube-QML - 0.6.1 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.3</source>
        <translation type="obsolete">cuteTube-QML - 0.6.3 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.6.5</source>
        <translation type="obsolete">cuteTube-QML - 0.6.5 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.0</source>
        <translation type="obsolete">cuteTube-QML - 0.7.0 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.1</source>
        <translation type="obsolete">cuteTube-QML - 0.7.1 in deutsch</translation>
    </message>
    <message>
        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="obsolete">Ein funktionsreicher YouTube Client für das Nokia N900. Diese experimentelle Veröffentlichung basiert auf QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.3</source>
        <translation type="obsolete">cuteTube-QML - 0.7.3 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.5</source>
        <translation type="obsolete">cuteTube-QML - 0.7.5 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.6</source>
        <translation type="obsolete">cuteTube-QML - 0.7.6 in deutsch</translation>
    </message>
    <message>
        <source>cuteTube-QML - 0.7.7</source>
        <translation type="obsolete">cuteTube-QML - 0.7.7 in deutsch</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="44"/>
        <source>cuteTube-QML - 0.8.0</source>
        <translation type="unfinished">cuteTube-QML - 0.8.0 in deutsch</translation>
    </message>
    <message>
        <location filename="../AboutDialog.qml" line="56"/>
        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountDetailsDialog</name>
    <message>
        <source>New account</source>
        <translation type="obsolete">Neues Konto</translation>
    </message>
    <message>
        <source>Edit account</source>
        <translation type="obsolete">Editieren Konto</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="10"/>
        <location filename="../AccountDetailsDialog.qml" line="26"/>
        <source>New Account</source>
        <translation>Neues Konto</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="15"/>
        <source>Edit Account</source>
        <translation>Konto bearbeiten</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="46"/>
        <source>Database error. Unable to save account</source>
        <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="82"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="95"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../AccountDetailsDialog.qml" line="108"/>
        <source>Default?</source>
        <translation>Standard?</translation>
    </message>
</context>
<context>
    <name>AccountsDialog</name>
    <message>
        <source>YouTube accounts</source>
        <translation type="obsolete">YouTube Konten</translation>
    </message>
    <message>
        <location filename="../AccountsDialog.qml" line="79"/>
        <source>YouTube Accounts</source>
        <translation>YouTube Konten</translation>
    </message>
</context>
<context>
    <name>AddCommentDialog</name>
    <message>
        <source>Add comment</source>
        <translation type="obsolete">Kommentieren</translation>
    </message>
    <message>
        <source>Share via </source>
        <translation type="obsolete">Teil uber </translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="6"/>
        <source>Add Comment</source>
        <translation>Kommentieren</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="15"/>
        <source>Share Via </source>
        <translation>Freigeben</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="60"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="74"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../AddCommentDialog.qml" line="111"/>
        <source>Message</source>
        <translation>Mitteilung</translation>
    </message>
</context>
<context>
    <name>AddToPlaylistDialog</name>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../AddToPlaylistDialog.qml" line="31"/>
        <source>Add To Playlist</source>
        <translation>Zur Wiedergabeliste hinzufügen</translation>
    </message>
</context>
<context>
    <name>ArchiveListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Delete from archive</source>
        <translation type="obsolete">Aus Archiv löschen</translation>
    </message>
    <message>
        <source>Delete from device</source>
        <translation type="obsolete">Vom Gerät löschen</translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="64"/>
        <source>Deleted from archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ArchiveListView.qml" line="67"/>
        <location filename="../ArchiveListView.qml" line="86"/>
        <source>Unable to delete from archive</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BusyDialog</name>
    <message>
        <location filename="../BusyDialog.qml" line="47"/>
        <source>Loading...</source>
        <translation>Lade...</translation>
    </message>
</context>
<context>
    <name>ChangeUserDialog</name>
    <message>
        <source>Change current user</source>
        <translation type="obsolete">Aktuellen Benutzer wechseln</translation>
    </message>
    <message>
        <location filename="../ChangeUserDialog.qml" line="50"/>
        <source>Change Current User</source>
        <translation>Aktuellen Benutzer wechseln</translation>
    </message>
</context>
<context>
    <name>CommentsDelegate</name>
    <message>
        <location filename="../CommentsDelegate.qml" line="20"/>
        <location filename="../CommentsDelegate.qml" line="22"/>
        <source>By </source>
        <translation>Von </translation>
    </message>
    <message>
        <location filename="../CommentsDelegate.qml" line="21"/>
        <location filename="../CommentsDelegate.qml" line="23"/>
        <source> on </source>
        <translation> am </translation>
    </message>
</context>
<context>
    <name>ConfirmExitDialog</name>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="47"/>
        <source>Hold it!</source>
        <translation>Stop!</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="58"/>
        <source>cuteTube is currently downloading. Do you really want to exit?</source>
        <translation>cuteTube läd gerade Dateien runter. Möchtest Du wirklich beenden?</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="71"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../ConfirmExitDialog.qml" line="81"/>
        <source>No</source>
        <translation>Nein</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <source>English</source>
        <translation type="obsolete">Englisch</translation>
    </message>
    <message>
        <source>German</source>
        <translation type="obsolete">Deutsch</translation>
    </message>
    <message>
        <source>Italian</source>
        <translation type="obsolete">Italienisch</translation>
    </message>
    <message>
        <source>Finnish</source>
        <translation type="obsolete">Finnisch</translation>
    </message>
    <message>
        <source>Dutch</source>
        <translation type="obsolete">Niederländisch</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation type="obsolete">Polnisch</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="222"/>
        <source>Video deleted from device</source>
        <translation>Video vom Gerät gelöscht</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="225"/>
        <source>Unable to delete video</source>
        <translation>Löschen des Videos nicht möglich</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="229"/>
        <source>Video not found</source>
        <translation>Video nicht gefunden</translation>
    </message>
    <message>
        <location filename="../../../controller.cpp" line="284"/>
        <source>Copied to clipboard</source>
        <translation>In Zwischenablage kopiert</translation>
    </message>
</context>
<context>
    <name>DownloadListDelegate</name>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pausiert</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">in Warteschlange</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">am Herrunterladen</translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>Failed</source>
        <translation type="obsolete">Fehlgeschlagen</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation type="obsolete">am Herrunterladen</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pausiert</translation>
    </message>
</context>
<context>
    <name>FileChooserDialog</name>
    <message>
        <source>Choose video file</source>
        <translation type="obsolete">Wähle eine Videodatei</translation>
    </message>
    <message>
        <location filename="../FileChooserDialog.qml" line="29"/>
        <source>Choose Video File</source>
        <translation>Wähle eine Videodatei</translation>
    </message>
</context>
<context>
    <name>HomeView</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Optionen</translation>
    </message>
    <message>
        <source>Accounts</source>
        <translation type="obsolete">Konto</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">Über</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="124"/>
        <source>My Channel</source>
        <translation>Mein Kanal</translation>
    </message>
    <message>
        <source>Most Recent</source>
        <translation type="obsolete">Aktuellste Videos</translation>
    </message>
    <message>
        <source>Most Viewed</source>
        <translation type="obsolete">Meistgesehen</translation>
    </message>
    <message>
        <location filename="../HomeView.qml" line="194"/>
        <source>Archive</source>
        <translation>Archiv</translation>
    </message>
</context>
<context>
    <name>InboxDelegate</name>
    <message>
        <location filename="../InboxDelegate.qml" line="44"/>
        <location filename="../InboxDelegate.qml" line="46"/>
        <source>From </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="45"/>
        <location filename="../InboxDelegate.qml" line="47"/>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source> on </source>
        <translation type="unfinished"> am </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="95"/>
        <source>By </source>
        <translation type="unfinished">Von </translation>
    </message>
    <message>
        <location filename="../InboxDelegate.qml" line="145"/>
        <source>Views</source>
        <translation type="unfinished">Aufrufe</translation>
    </message>
</context>
<context>
    <name>InboxDialog</name>
    <message>
        <location filename="../InboxDialog.qml" line="57"/>
        <source>Inbox</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../InboxDialog.qml" line="69"/>
        <source>No messages found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuBar</name>
    <message>
        <source>Menu</source>
        <translation type="obsolete">Menü</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="obsolete">Zurück</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="obsolete">Beenden</translation>
    </message>
    <message>
        <location filename="../MenuBar.qml" line="133"/>
        <source>Sort</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MyAccountView</name>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Video hochladen</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="98"/>
        <source>My Uploads</source>
        <translation>Mein Uploads</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="104"/>
        <source>Uploads</source>
        <translation>Uploads</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="122"/>
        <source>My Favourites</source>
        <translation>Mein Favoriten</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="128"/>
        <source>Favourites</source>
        <translation>Favoriten</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="152"/>
        <source>Playlists</source>
        <translation>Wiedergabelisten</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="176"/>
        <source>Subscriptions</source>
        <translation>Abonnement</translation>
    </message>
    <message>
        <location filename="../MyAccountView.qml" line="191"/>
        <source>Signed in as:</source>
        <translation>Angemeldet als:</translation>
    </message>
</context>
<context>
    <name>NewPlaylistDialog</name>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Neue Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="34"/>
        <source>New Playlist</source>
        <translation>Neue Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="46"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="59"/>
        <source>Description (optional)</source>
        <translation>Beschreibung (optional)</translation>
    </message>
    <message>
        <location filename="../NewPlaylistDialog.qml" line="71"/>
        <source>Private?</source>
        <translation>Privat?</translation>
    </message>
</context>
<context>
    <name>NoAccountDialog</name>
    <message>
        <location filename="../NoAccountDialog.qml" line="60"/>
        <source>Hi there!</source>
        <translation>Na Du!</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="71"/>
        <source>My name&apos;s Cutey. My buddy Clippy tells me it&apos;s the first time you&apos;ve used cuteTube. Would you like to add a YouTube account?</source>
        <translation>Mein Name ist Cutey. Mein Kumpel Clippy hat mir verraten dass Du cuteTube zum ersten Mal benutzt. Möchtest Du ein YouTube Konto anlegen?</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="84"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../NoAccountDialog.qml" line="98"/>
        <source>Go Away</source>
        <translation>Weggehen</translation>
    </message>
</context>
<context>
    <name>NotificationArea</name>
    <message>
        <location filename="../NotificationArea.qml" line="55"/>
        <source>No active downloads</source>
        <translation>Keine aktiven Downloads</translation>
    </message>
    <message>
        <location filename="../NotificationArea.qml" line="151"/>
        <source>Downloads</source>
        <translation>Downloads</translation>
    </message>
</context>
<context>
    <name>OAuthDialog</name>
    <message>
        <location filename="../OAuthDialog.qml" line="8"/>
        <source>Authorisation For </source>
        <translation>Angemeldet als </translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="27"/>
        <source>Error obtaining facebook authorisation</source>
        <translation>Anmeldung bei Facebook schlug fehl</translation>
    </message>
    <message>
        <location filename="../OAuthDialog.qml" line="117"/>
        <source>Enter pin code</source>
        <translation>Pin Code eingeben</translation>
    </message>
</context>
<context>
    <name>PlaylistDelegate</name>
    <message>
        <location filename="../PlaylistDelegate.qml" line="31"/>
        <source> videos</source>
        <translation>Videos</translation>
    </message>
</context>
<context>
    <name>PlaylistVideosView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Video herrunterladen</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Audio herrunterladen</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">In Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="71"/>
        <source>Video(s) deleted from playlist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../PlaylistVideosView.qml" line="92"/>
        <source>No videos found</source>
        <translation>Keine Videos gefunden</translation>
    </message>
</context>
<context>
    <name>PlaylistsView</name>
    <message>
        <location filename="../PlaylistsView.qml" line="58"/>
        <source>New playlist created</source>
        <translation>Neue Wiedergabeliste erstellt</translation>
    </message>
    <message>
        <source>New playlist</source>
        <translation type="obsolete">Neue Wiedergabeliste</translation>
    </message>
    <message>
        <location filename="../PlaylistsView.qml" line="106"/>
        <source>No playlists found</source>
        <translation>Keine Wiedergabelisten gefunden</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <location filename="../ProxyDialog.qml" line="30"/>
        <source>Network Proxy</source>
        <translation type="unfinished">Netzwerk Proxy</translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="44"/>
        <source>Host (e.g. 192.168.100.1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ProxyDialog.qml" line="51"/>
        <source>Port (e.g. 8080)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Date</source>
        <translation type="obsolete">Datum</translation>
    </message>
    <message>
        <source>Relevance</source>
        <translation type="obsolete">Relevanz</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation type="obsolete">Bewertung</translation>
    </message>
    <message>
        <source>Views</source>
        <translation type="obsolete">Aufrufe</translation>
    </message>
    <message>
        <location filename="../SearchBar.qml" line="183"/>
        <source>Order by:</source>
        <translation>Sortieren nach:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../SettingsDialog.qml" line="217"/>
        <source>Your saved searches have been cleared</source>
        <translation>Die gespeicherten Suchen wurden gelöscht</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="220"/>
        <source>Database error. Unable to clear searches</source>
        <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="267"/>
        <source>Settings</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="333"/>
        <source>Playback quality</source>
        <translation>Wiedergabequalität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="342"/>
        <source>Download quality</source>
        <translation>Downloadqualität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="308"/>
        <source>Start downloads</source>
        <translation>Downloads starten</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="410"/>
        <source>Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="435"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="443"/>
        <source>Download location</source>
        <translation>Downloadverzeichnis</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="452"/>
        <source>Screen orientation</source>
        <translation>Bildschirmausrichtung</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="324"/>
        <source>Media player</source>
        <translation>Media Player</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="193"/>
        <location filename="../SettingsDialog.qml" line="427"/>
        <location filename="../SettingsDialog.qml" line="429"/>
        <source>Language</source>
        <translation>Sprache</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>High quality</source>
        <translation>Hohe Qualität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>360p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>480p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>720p</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Portuguese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most recent</source>
        <translation>Aktuellste videos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="48"/>
        <source>Most viewed</source>
        <translation>Meistgesehen</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Archive</source>
        <translation>Archiv</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="49"/>
        <source>Latest subscription videos</source>
        <translation>Letzte abonnierte videos</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My uploads</source>
        <translation>Mein uploads</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="50"/>
        <source>My favourites</source>
        <translation>Mein favoriten</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="136"/>
        <location filename="../SettingsDialog.qml" line="196"/>
        <source>Network Proxy</source>
        <translation>Netzwerk Proxy</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="160"/>
        <location filename="../SettingsDialog.qml" line="335"/>
        <source>Playback Quality</source>
        <translation>Wiedergabequalität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="163"/>
        <location filename="../SettingsDialog.qml" line="344"/>
        <source>Download Quality</source>
        <translation>Downloadqualität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="166"/>
        <location filename="../SettingsDialog.qml" line="310"/>
        <source>Start Downloads</source>
        <translation>Downloads starten</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="172"/>
        <location filename="../SettingsDialog.qml" line="360"/>
        <source>Category Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="175"/>
        <location filename="../SettingsDialog.qml" line="369"/>
        <source>Category Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="178"/>
        <location filename="../SettingsDialog.qml" line="378"/>
        <source>Order Category Videos By</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="184"/>
        <location filename="../SettingsDialog.qml" line="454"/>
        <source>Screen Orientation</source>
        <translation>Bildschirmausrichtung</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="187"/>
        <location filename="../SettingsDialog.qml" line="326"/>
        <source>Media Player</source>
        <translation>Media Player</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="350"/>
        <source>YouTube categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="358"/>
        <source>Category feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="367"/>
        <source>Category feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="376"/>
        <source>Order category videos by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="468"/>
        <source>Widget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="476"/>
        <source>Feed one</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="485"/>
        <source>Feed two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="494"/>
        <source>Feed three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="503"/>
        <source>Feed four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="40"/>
        <location filename="../SettingsDialog.qml" line="41"/>
        <source>Mobile</source>
        <translation>Mobil</translation>
    </message>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Hohe Qualität</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Automatically</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="42"/>
        <source>Manually</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>On</source>
        <translation>An</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="43"/>
        <source>Off</source>
        <translation>Aus</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Automatic</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Landscape</source>
        <translation>Querformat</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="44"/>
        <source>Portrait</source>
        <translation>Hochformat</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Light</source>
        <translation>Hell</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="45"/>
        <source>Dark</source>
        <translation>Dunkel</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>English</source>
        <translation>Englisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>German</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Finnish</source>
        <translation>Finnisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Italian</source>
        <translation>Italienisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="46"/>
        <source>Dutch</source>
        <translation>Niederländisch</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="47"/>
        <source>Polish</source>
        <translation>Polnisch</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation type="obsolete">in Warteschlange</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pausiert</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="121"/>
        <source>Your settings have been saved</source>
        <translation>Ihre Einstellungen wurden gespeichert</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="126"/>
        <location filename="../SettingsDialog.qml" line="169"/>
        <source>Download Path</source>
        <translation>Downloadverzeichnis</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="128"/>
        <source>Download Location</source>
        <translation>Downloadverzeichnis</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="181"/>
        <location filename="../SettingsDialog.qml" line="394"/>
        <source>Safe Search</source>
        <translation>Sicherer Modus</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="190"/>
        <location filename="../SettingsDialog.qml" line="418"/>
        <location filename="../SettingsDialog.qml" line="420"/>
        <source>Theme</source>
        <translation>Thema</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="199"/>
        <location filename="../SettingsDialog.qml" line="478"/>
        <source>Widget Feed One</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="202"/>
        <location filename="../SettingsDialog.qml" line="487"/>
        <source>Widget Feed Two</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="205"/>
        <location filename="../SettingsDialog.qml" line="496"/>
        <source>Widget Feed Three</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="208"/>
        <location filename="../SettingsDialog.qml" line="505"/>
        <source>Widget Feed Four</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="291"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="299"/>
        <source>Network proxy</source>
        <translation>Netzwerk proxy</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="316"/>
        <source>Media</source>
        <translation>Medien</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="384"/>
        <source>YouTube searches</source>
        <translation>YouTube suche</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="392"/>
        <source>Safe search</source>
        <translation>Sicher suchlauf</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="300"/>
        <source>None</source>
        <translation>Kein proxy</translation>
    </message>
    <message>
        <location filename="../SettingsDialog.qml" line="403"/>
        <source>Clear saved searches</source>
        <translation>Lösche Suche</translation>
    </message>
</context>
<context>
    <name>Sharing</name>
    <message>
        <location filename="../../../sharing.cpp" line="78"/>
        <source>Error - Server repsonse is: </source>
        <translation>Fehler - Serverantwort ist:</translation>
    </message>
</context>
<context>
    <name>SubscriptionsView</name>
    <message>
        <location filename="../SubscriptionsView.qml" line="36"/>
        <source>Latest Subscriptions Videos</source>
        <translation>Letzte abonnierte Videos</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="45"/>
        <source>You have unsubscribed to this channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have unsubscribed to &apos;</source>
        <translation type="obsolete">Du hast ein Abonnement bei </translation>
    </message>
    <message>
        <source>Latest Subscription Videos</source>
        <translation type="obsolete">Letzte abonnierte Videos</translation>
    </message>
    <message>
        <location filename="../SubscriptionsView.qml" line="104"/>
        <source>No subscriptions found</source>
        <translation>Keine Abonnements gefunden</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Cars &amp; Vehicles</source>
        <translation>Autos &amp; Fahrzeuge</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="70"/>
        <source>Comedy</source>
        <translation>Comedy</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Education</source>
        <translation>Bildung</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="13"/>
        <location filename="../UploadDialog.qml" line="71"/>
        <source>Entertainment</source>
        <translation>Unterhaltung</translation>
    </message>
    <message>
        <source>Film and Animation</source>
        <translation type="obsolete">Film und Animation</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Gaming</source>
        <translation>Spiele</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="72"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Howto &amp; Style</source>
        <translation>Tips &amp; Tricks</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="73"/>
        <source>News &amp; Politics</source>
        <translation>Nachrichten und Politik</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>Non-profits &amp; Activism</source>
        <translation>Gemeinnütziges Engagement</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="74"/>
        <source>People &amp; Blogs</source>
        <translation>Leute &amp; Blogs</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Pets &amp; Animals</source>
        <translation>Tiere</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="75"/>
        <source>Science &amp; Technology</source>
        <translation>Wissenschaft &amp; Technik</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Sport</source>
        <translation>Sport</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="76"/>
        <source>Travel &amp; Events</source>
        <translation>Reisen &amp; Events</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="29"/>
        <location filename="../UploadDialog.qml" line="220"/>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="118"/>
        <source>Upload Video</source>
        <translation>Video hochladen</translation>
    </message>
    <message>
        <source>Upload video</source>
        <translation type="obsolete">Video hochladen</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="143"/>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="152"/>
        <location filename="../UploadDialog.qml" line="228"/>
        <source>None chosen</source>
        <translation>Keins ausgewählt</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="168"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="181"/>
        <source>Description (optional)</source>
        <translation>Beschreibung (optional)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="193"/>
        <source>Tags (seperated by commas)</source>
        <translation>Tags (durch Kommata getrennt)</translation>
    </message>
    <message>
        <location filename="../UploadDialog.qml" line="206"/>
        <source>Private?</source>
        <translation>Privat?</translation>
    </message>
</context>
<context>
    <name>UploadProgressDialog</name>
    <message>
        <source>Upload progress</source>
        <translation type="obsolete">Upload Fortschritt</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="6"/>
        <source>Starting upload</source>
        <translation>Upload startet</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="30"/>
        <source>Upload Progress</source>
        <translation>Upload Fortschritt</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="42"/>
        <source>Filename</source>
        <translation>Dateiname</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="57"/>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Abort</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <source>Close</source>
        <translation>Ende</translation>
    </message>
    <message>
        <location filename="../UploadProgressDialog.qml" line="91"/>
        <location filename="../UploadProgressDialog.qml" line="97"/>
        <location filename="../UploadProgressDialog.qml" line="115"/>
        <source>Upload is in progress</source>
        <translation>Upload in Arbeit</translation>
    </message>
</context>
<context>
    <name>UserInfoDialog</name>
    <message>
        <location filename="../UserInfoDialog.qml" line="127"/>
        <source>Subscribers</source>
        <translation>Abonnenten</translation>
    </message>
    <message>
        <location filename="../UserInfoDialog.qml" line="141"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
</context>
<context>
    <name>UserVideosView</name>
    <message>
        <location filename="../UserVideosView.qml" line="131"/>
        <source>You have subscribed to &apos;</source>
        <translation>Du hast ein Abonnement bei</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="135"/>
        <source>You have unsubscribed to &apos;</source>
        <translation>Abonnement gekündigt bei</translation>
    </message>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Video herrunterladen</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Audio herrunterladen</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">In Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="155"/>
        <source>No videos found</source>
        <translation>Keine Videos gefunden</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="214"/>
        <source>Subscribers</source>
        <translation>Abonnenten</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="228"/>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="251"/>
        <source>Unsubscribe</source>
        <translation>Abonnement kündigen</translation>
    </message>
    <message>
        <location filename="../UserVideosView.qml" line="251"/>
        <source>Subscribe</source>
        <translation>Abonnieren</translation>
    </message>
</context>
<context>
    <name>VideoInfoView</name>
    <message>
        <location filename="../VideoInfoView.qml" line="15"/>
        <source>No description</source>
        <translation>Keine Beschreibung</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="93"/>
        <source>Your comment has been added</source>
        <translation>Dein Kommentar wurde hinzugefügt</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="96"/>
        <source>Your rating has been added</source>
        <translation>Deine Bewertung wurde hinzugefügt</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="103"/>
        <source>Video shared on facebook</source>
        <translation>Video auf Facebook freigegeben</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">In Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Share via facebook</source>
        <translation type="obsolete">Auf Facebook freigeben</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="439"/>
        <location filename="../VideoInfoView.qml" line="464"/>
        <location filename="../VideoInfoView.qml" line="578"/>
        <source>You are not signed in to a YouTube account</source>
        <translation>Nicht bei einem YouTube Konto angemeldet</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="245"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="284"/>
        <source>Comments</source>
        <translation>Kommentare</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="323"/>
        <source>Related</source>
        <translation>Ähnliche</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="408"/>
        <location filename="../VideoInfoView.qml" line="411"/>
        <source>By </source>
        <translation>Von </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="410"/>
        <location filename="../VideoInfoView.qml" line="413"/>
        <source> on </source>
        <translation> am </translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="481"/>
        <source>Views</source>
        <translation>Aufrufe</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="495"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="511"/>
        <source>Tags</source>
        <translation>Tags</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="521"/>
        <source>No tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="590"/>
        <source>No comments</source>
        <translation>Keine Kommentare</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="590"/>
        <source> comments</source>
        <translation>Kommentare</translation>
    </message>
    <message>
        <location filename="../VideoInfoView.qml" line="706"/>
        <source>No related videos</source>
        <translation>Keine ähnlichen Videos</translation>
    </message>
</context>
<context>
    <name>VideoListDelegate</name>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source>By </source>
        <translation>Von </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="52"/>
        <source> on </source>
        <translation> am </translation>
    </message>
    <message>
        <location filename="../VideoListDelegate.qml" line="102"/>
        <source>Views</source>
        <translation>Aufrufe</translation>
    </message>
</context>
<context>
    <name>VideoListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Video herrunterladen</translation>
    </message>
    <message>
        <source>Download audio</source>
        <translation type="obsolete">Audio herrunterladen</translation>
    </message>
    <message>
        <source>Add to favourites</source>
        <translation type="obsolete">Zu Favoriten hinzufügen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation type="obsolete">Zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">In Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="82"/>
        <source>Video(s) deleted from favourites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../VideoListView.qml" line="104"/>
        <source>No videos found</source>
        <translation>Keine Videos gefunden</translation>
    </message>
</context>
<context>
    <name>VideoPlaybackView</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
    </message>
</context>
<context>
    <name>Widget</name>
    <message>
        <source>Error: Unable to retrieve video</source>
        <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Keine Videos gefunden</translation>
    </message>
</context>
<context>
    <name>XHamsterInfoView</name>
    <message>
        <source>Info</source>
        <translation type="obsolete">Info</translation>
    </message>
    <message>
        <source>Related</source>
        <translation type="obsolete">Ähnliche</translation>
    </message>
    <message>
        <source>By </source>
        <translation type="obsolete">Von </translation>
    </message>
    <message>
        <source> on </source>
        <translation type="obsolete"> am </translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Aufrufe</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="obsolete">Tags</translation>
    </message>
</context>
<context>
    <name>XHamsterListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Video herrunterladen</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Keine Videos gefunden</translation>
    </message>
</context>
<context>
    <name>YouJizzInfoView</name>
    <message>
        <source>Copy to clipboard</source>
        <translation type="obsolete">In Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Info</translation>
    </message>
    <message>
        <source>Related</source>
        <translation type="obsolete">Ähnliche</translation>
    </message>
    <message>
        <source>Views </source>
        <translation type="obsolete">Aufrufe</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation type="obsolete">Tags</translation>
    </message>
</context>
<context>
    <name>YouJizzListView</name>
    <message>
        <source>Multi-select</source>
        <translation type="obsolete">Mehrfachauswahl</translation>
    </message>
    <message>
        <source>Download video</source>
        <translation type="obsolete">Video herrunterladen</translation>
    </message>
    <message>
        <source>No videos found</source>
        <translation type="obsolete">Keine Videos gefunden</translation>
    </message>
</context>
<context>
    <name>YouTube</name>
    <message>
        <location filename="../../../youtube.cpp" line="43"/>
        <source>Error obtaining access token</source>
        <translation>Fehler beim Zugangscode</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="54"/>
        <source>Authentication failed</source>
        <translation>Autorisierung schlug fehl</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="58"/>
        <source>You are signed in to YouTube as &apos;</source>
        <translation>Bei YouTube angemeldet als &apos;</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="120"/>
        <location filename="../../../youtube.cpp" line="226"/>
        <source>Error - Server repsonse is: </source>
        <translation>Fehler - Serverantwort ist:</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="170"/>
        <location filename="../../../youtube.cpp" line="178"/>
        <source>Upload aborted</source>
        <translation>Upload abgebrochen</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="185"/>
        <source>Upload interrupted. Attempting to resume...</source>
        <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="189"/>
        <source>Upload failed</source>
        <translation>Upload fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="195"/>
        <source>Upload is completed</source>
        <translation>Upload ist komplett</translation>
    </message>
    <message>
        <location filename="../../../youtube.cpp" line="397"/>
        <location filename="../../../youtube.cpp" line="439"/>
        <source>Error: Unable to retrieve video</source>
        <translation>Fehler: Kann Video nicht empfangen</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Dunkel</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="obsolete">Hell</translation>
    </message>
    <message>
        <location filename="../main.qml" line="157"/>
        <source>Video(s) added to download queue</source>
        <translation>Video(s) in Warteschlange eingefügt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="160"/>
        <source>Video(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="171"/>
        <source>Audio track(s) added to download queue</source>
        <translation>Audio Tracks in Warteschlange eingefügt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="174"/>
        <source>Audio track(s) already in download queue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video added to favourites</source>
        <translation type="obsolete">Video wurde zu Favoriten hinzugefügt</translation>
    </message>
    <message>
        <source>Video added to playlist</source>
        <translation type="obsolete">Video wurde zur Wiedergabeliste hinzugefügt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="214"/>
        <source>New playlist created</source>
        <translation>Neue Wiedergabeliste erstellt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Converting</source>
        <translation>Konvertiere</translation>
    </message>
    <message>
        <location filename="../main.qml" line="264"/>
        <source>Conversion of &apos;</source>
        <translation>Unterhaltung zwischen &apos;</translation>
    </message>
    <message>
        <location filename="../main.qml" line="33"/>
        <source>Cars &amp; Vehicles</source>
        <translation type="unfinished">Autos &amp; Fahrzeuge</translation>
    </message>
    <message>
        <location filename="../main.qml" line="33"/>
        <source>Comedy</source>
        <translation type="unfinished">Comedy</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Education</source>
        <translation type="unfinished">Bildung</translation>
    </message>
    <message>
        <location filename="../main.qml" line="34"/>
        <source>Entertainment</source>
        <translation type="unfinished">Unterhaltung</translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Film &amp; Animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.qml" line="35"/>
        <source>Gaming</source>
        <translation type="unfinished">Spiele</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Howto &amp; Style</source>
        <translation type="unfinished">Tips &amp; Tricks</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>Music</source>
        <translation type="unfinished">Musik</translation>
    </message>
    <message>
        <location filename="../main.qml" line="36"/>
        <source>News &amp; Politics</source>
        <translation type="unfinished">Nachrichten und Politik</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>Non-profits &amp; Activism</source>
        <translation type="unfinished">Gemeinnütziges Engagement</translation>
    </message>
    <message>
        <location filename="../main.qml" line="37"/>
        <source>People &amp; Blogs</source>
        <translation type="unfinished">Leute &amp; Blogs</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Pets &amp; Animals</source>
        <translation type="unfinished">Tiere</translation>
    </message>
    <message>
        <location filename="../main.qml" line="38"/>
        <source>Science &amp; Technology</source>
        <translation type="unfinished">Wissenschaft &amp; Technik</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Sport</source>
        <translation type="unfinished">Sport</translation>
    </message>
    <message>
        <location filename="../main.qml" line="39"/>
        <source>Travel &amp; Events</source>
        <translation type="unfinished">Reisen &amp; Events</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Relevance</source>
        <translation type="unfinished">Relevanz</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Date</source>
        <translation type="unfinished">Datum</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Views</source>
        <translation type="unfinished">Aufrufe</translation>
    </message>
    <message>
        <location filename="../main.qml" line="41"/>
        <source>Rating</source>
        <translation type="unfinished">Bewertung</translation>
    </message>
    <message>
        <location filename="../main.qml" line="205"/>
        <source>Video(s) added to favourites</source>
        <translation>Video(s) wurde zu Favoriten hinzugefügt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="206"/>
        <source>Video(s) added to playlist</source>
        <translation>Video(s) wurde zur Wiedergabeliste hinzugefügt</translation>
    </message>
    <message>
        <location filename="../main.qml" line="264"/>
        <source>&apos; failed</source>
        <translation>&apos; gescheitert</translation>
    </message>
    <message>
        <source>High quality</source>
        <translation type="obsolete">Hohe qualität</translation>
    </message>
    <message>
        <source>Mobile</source>
        <translation type="obsolete">Mobil</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Queued</source>
        <translation>in Warteschlange</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Paused</source>
        <translation>Pausiert</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Downloading</source>
        <translation>am Herrunterladen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="279"/>
        <source>Failed</source>
        <translation>Fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Most Recent</source>
        <translation>Aktuellste Videos</translation>
    </message>
    <message>
        <location filename="../main.qml" line="40"/>
        <source>Most Viewed</source>
        <translation>Meistgesehen</translation>
    </message>
</context>
<context>
    <name>mainscripts</name>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Media Player</translation>
    </message>
    <message>
        <source>My Channel</source>
        <translation type="obsolete">Mein Kanal</translation>
    </message>
    <message>
        <source>Archive</source>
        <translation type="obsolete">Archiv</translation>
    </message>
    <message>
        <source>My Playlists</source>
        <translation type="obsolete">Mein Wiedergabelisten</translation>
    </message>
    <message>
        <source>My Subscriptions</source>
        <translation type="obsolete">Mein Abonnement</translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Video Info</translation>
    </message>
    <message>
        <source>Video Playback</source>
        <translation type="obsolete">Video abspielen</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="obsolete">Downloads</translation>
    </message>
    <message>
        <source>date</source>
        <translation type="obsolete">datum</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">aufrufe</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">relevanz</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">bewertung</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Suchlauf</translation>
    </message>
</context>
<context>
    <name>settings</name>
    <message>
        <source>High Quality</source>
        <translation type="obsolete">Hohe Qualität</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="obsolete">Pausiert</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation type="obsolete">Automatisch</translation>
    </message>
    <message>
        <source>Media Player</source>
        <translation type="obsolete">Media Player</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="obsolete">Datum</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation type="obsolete">Dunkel</translation>
    </message>
    <message>
        <source>English</source>
        <translation type="obsolete">Englisch</translation>
    </message>
</context>
<context>
    <name>xtube</name>
    <message>
        <source>date</source>
        <translation type="obsolete">datum</translation>
    </message>
    <message>
        <source>views</source>
        <translation type="obsolete">aufrufe</translation>
    </message>
    <message>
        <source>rating</source>
        <translation type="obsolete">bewertung</translation>
    </message>
    <message>
        <source>Search </source>
        <translation type="obsolete">Suche</translation>
    </message>
    <message>
        <source>Video Info</source>
        <translation type="obsolete">Video Info</translation>
    </message>
    <message>
        <source>relevance</source>
        <translation type="obsolete">relevanz</translation>
    </message>
</context>
</TS>
